=======
PyDracs
=======


.. image:: https://img.shields.io/pypi/v/pydracs.svg
        :target: https://pypi.python.org/pypi/pydracs

.. image:: https://img.shields.io/travis/cfekete93/pydracs.svg
        :target: https://travis-ci.org/cfekete93/pydracs

.. image:: https://readthedocs.org/projects/pydracs/badge/?version=latest
        :target: https://pydracs.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Distributed control and communications system mainly targeted at single board computers such as the raspberry pi.


* Free software: MIT license
* Documentation: https://pydracs.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
